==> jboss-4.0.2.zip: testsuite/src/main/org/jboss/test/txtimer/ejb/TimerFacadeBean.java <==
/*
* JBoss, the OpenSource J2EE webOS
*
* Distributable under LGPL license.
* See terms of license at gnu.org.
*/
package org.jboss.test.txtimer.ejb;

import org.apache.log4j.Logger;
import org.jboss.test.txtimer.interfaces.TimerEntityHome;
import org.jboss.test.txtimer.interfaces.TimerEntity;
import org.jboss.test.txtimer.interfaces.TimerSessionHome;
import org.jboss.test.txtimer.interfaces.TimerSession;

import javax.ejb.*;
import javax.naming.InitialContext;
import java.rmi.RemoteException;

/**
 * Session Bean Timer Test
 *
 * @ejb.bean name="test/txtimer/TimerFacade"
 * display-name="TimerFacade Session Bean"
 * type="Stateless"
 * transaction-type="Container"
 * view-type="remote"
 * @ejb.transaction type="Required"
 */
public class TimerFacadeBean implements SessionBean
{
   private static Logger log = Logger.getLogger(TimerFacadeBean.class);

   private SessionContext context;

   /**
    * @ejb.interface-method view-type="both"
    */
   public void rollbackAfterCreateSession(long duration)
           throws Exception
   {
      InitialContext iniCtx = new InitialContext();
      TimerSessionHome home = (TimerSessionHome) iniCtx.lookup(TimerSessionHome.JNDI_NAME);
      TimerSession bean = home.create();
      bean.createTimer(duration, 0, null);
      context.setRollbackOnly();
   }

   /**
    * @ejb.interface-method view-type="both"
    */
   public void rollbackAfterCancelSession()
           throws Exception
   {
      InitialContext iniCtx = new InitialContext();
      TimerSessionHome home = (TimerSessionHome) iniCtx.lookup(TimerSessionHome.JNDI_NAME);
      TimerSession bean = home.create();
      bean.cancelFirstTimer();
      context.setRollbackOnly();
   }

   /**
    * @ejb.interface-method view-type="both"
    */
   public void rollbackAfterCreateEntity(long duration)
           throws Exception
   {
      InitialContext iniCtx = new InitialContext();
      TimerEntityHome home = (TimerEntityHome) iniCtx.lookup(TimerEntityHome.JNDI_NAME);
      TimerEntity bean = home.findByPrimaryKey(new Integer(1));
      bean.createTimer(duration, 0, null);
      context.setRollbackOnly();
   }

   /**
    * @ejb.interface-method view-type="both"
    */
   public void rollbackAfterCancelEntity()
           throws Exception
   {
      InitialContext iniCtx = new InitialContext();
      TimerEntityHome home = (TimerEntityHome) iniCtx.lookup(TimerEntityHome.JNDI_NAME);
      TimerEntity bean = home.findByPrimaryKey(new Integer(1));
      bean.cancelFirstTimer();
      context.setRollbackOnly();
   }


   // -------------------------------------------------------------------------
   // Framework Callbacks
   // -------------------------------------------------------------------------
   
   public void setSessionContext(SessionContext ctx) throws EJBException, RemoteException
   {
      this.context = ctx;
   }

   /**
    * @ejb.create-method view-type="both"
    */
   public void ejbCreate() throws CreateException
   {
   }

   public void ejbRemove() throws EJBException, RemoteException
   {
   }

   public void ejbActivate() throws EJBException, RemoteException
   {
   }

   public void ejbPassivate() throws EJBException, RemoteException
   {
   }
}

==> jboss-4.0.4.zip: testsuite/src/main/org/jboss/test/txtimer/ejb/TimerFacadeBean.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.test.txtimer.ejb;

import java.rmi.RemoteException;

import javax.ejb.CreateException;
import javax.ejb.EJBException;
import javax.ejb.SessionBean;
import javax.ejb.SessionContext;
import javax.naming.InitialContext;

import org.apache.log4j.Logger;
import org.jboss.test.txtimer.interfaces.TimerEntity;
import org.jboss.test.txtimer.interfaces.TimerEntityHome;
import org.jboss.test.txtimer.interfaces.TimerSession;
import org.jboss.test.txtimer.interfaces.TimerSessionHome;

/**
 * Session Bean Timer Test
 */
public class TimerFacadeBean implements SessionBean
{
   private static Logger log = Logger.getLogger(TimerFacadeBean.class);

   private SessionContext context;

   /**
    * @ejb.interface-method view-type="both"
    */
   public void rollbackAfterCreateSession(long duration)
           throws Exception
   {
      InitialContext iniCtx = new InitialContext();
      TimerSessionHome home = (TimerSessionHome) iniCtx.lookup(TimerSessionHome.JNDI_NAME);
      TimerSession bean = home.create();
      bean.createTimer(duration, 0, null);
      context.setRollbackOnly();
   }

   /**
    * @ejb.interface-method view-type="both"
    */
   public void rollbackAfterCancelSession()
           throws Exception
   {
      InitialContext iniCtx = new InitialContext();
      TimerSessionHome home = (TimerSessionHome) iniCtx.lookup(TimerSessionHome.JNDI_NAME);
      TimerSession bean = home.create();
      bean.cancelFirstTimer();
      context.setRollbackOnly();
   }

   /**
    * @ejb.interface-method view-type="both"
    */
   public void rollbackAfterCreateEntity(long duration)
           throws Exception
   {
      InitialContext iniCtx = new InitialContext();
      TimerEntityHome home = (TimerEntityHome) iniCtx.lookup(TimerEntityHome.JNDI_NAME);
      TimerEntity bean = home.findByPrimaryKey(new Integer(1));
      bean.createTimer(duration, 0, null);
      context.setRollbackOnly();
   }

   /**
    * @ejb.interface-method view-type="both"
    */
   public void rollbackAfterCancelEntity()
           throws Exception
   {
      InitialContext iniCtx = new InitialContext();
      TimerEntityHome home = (TimerEntityHome) iniCtx.lookup(TimerEntityHome.JNDI_NAME);
      TimerEntity bean = home.findByPrimaryKey(new Integer(1));
      bean.cancelFirstTimer();
      context.setRollbackOnly();
   }


   // -------------------------------------------------------------------------
   // Framework Callbacks
   // -------------------------------------------------------------------------
   
   public void setSessionContext(SessionContext ctx) throws EJBException, RemoteException
   {
      this.context = ctx;
   }

   /**
    * @ejb.create-method view-type="both"
    */
   public void ejbCreate() throws CreateException
   {
   }

   public void ejbRemove() throws EJBException, RemoteException
   {
   }

   public void ejbActivate() throws EJBException, RemoteException
   {
   }

   public void ejbPassivate() throws EJBException, RemoteException
   {
   }
}
